from .KPI import KPIVisual
from .Table import TableVisual
from .Card import CardVisual
from .Pie import PieVisual
from .Bar import BarVisual
from .Scatter import ScatterVisual
from .Line import LineVisual
from .Checklist import ChecklistVisual
from .Histogram import HistogramVisual
from .Heatmap import HeatmapVisual
from .Gauge import GaugeVisual
from .Boxplot import BoxplotVisual

__ALL__ = [
    KPIVisual,
    TableVisual,
    CardVisual,
    PieVisual,
    BarVisual,
    ScatterVisual,
    LineVisual,
    ChecklistVisual,
    HistogramVisual,
    HeatmapVisual,
    GaugeVisual,
    BoxplotVisual
]